From Irene Ruengeler: Whitespace changes.
[obnox/wireshark/wip.git] / filters.h
index cbea1b9c566626bd46bb18ce0c2e06cfcb075979..bfb3f93c2b832adf6327f3a255f9eada95e55067 100644 (file)
--- a/filters.h
+++ b/filters.h
@@ -1,10 +1,10 @@
-/* filters.c
+/* filters.h
  * Declarations of routines for reading and writing the filters file.
  *
- * $Id: filters.h,v 1.4 2003/12/04 00:45:37 guy Exp $
+ * $Id$
  *
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
  *
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#ifndef FILTERS_H
+#define FILTERS_H
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /*
  * Filter lists.
  */
 typedef enum {
-       CFILTER_LIST,   /* capture filter list */
-       DFILTER_LIST    /* display filter list */
+       CFILTER_LIST,           /* capture filter list - saved */
+       DFILTER_LIST,           /* display filter list - saved */
+       CFILTER_EDITED_LIST,    /* capture filter list - currently edited */
+       DFILTER_EDITED_LIST     /* display filter list - currently edited */
 } filter_list_type_t;
 
 /*
@@ -47,7 +56,7 @@ typedef struct {
  * the file we tried to read - it should be freed by our caller -
  * and "*errno_return" is set to the error.
  */
-void read_filter_list(filter_list_type_t list, char **pref_path_return,
+void read_filter_list(filter_list_type_t list_type, char **pref_path_return,
     int *errno_return);
 
 /*
@@ -75,5 +84,16 @@ void remove_from_filter_list(filter_list_type_t list, GList *fl_entry);
  * the file we tried to read - it should be freed by our caller -
  * and "*errno_return" is set to the error.
  */
-void save_filter_list(filter_list_type_t list, char **pref_path_return,
+void save_filter_list(filter_list_type_t list_type, char **pref_path_return,
     int *errno_return);
+
+/*
+ * Clone the filter list so it can be edited.
+ */
+void copy_filter_list(filter_list_type_t dest_type, filter_list_type_t src_type);
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* FILTERS_H */